<?php

if (!defined('ABSPATH')) {
    exit;
}

class Adventure_blog_Social_Menu extends Adventure_blog_Widget_Base
{

    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->widget_cssclass = 'widget_adventure_blog_social_menu';
        $this->widget_description = __("Displays social menu if you have set it.", 'adventure-blog');
        $this->widget_id = 'adventure_blog_social_menu';
        $this->widget_name = __('Adventure Blog: Social Menu', 'adventure-blog');
        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Title', 'adventure-blog'),
            ),
            'style' => array(
                'type' => 'select',
                'label' => __('Style', 'adventure-blog'),
                'options' => array(
                    'style_1' => __('Style 1', 'adventure-blog'),
                    'style_2' => __('Style 2', 'adventure-blog'),
                    'style_3' => __('Style 3', 'adventure-blog'),
                ),
                'std' => 'style_1',
            ),
        );

        parent::__construct();
    }

    /**
     * Output widget.
     *
     * @see WP_Widget
     *
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        ob_start();

        $this->widget_start($args, $instance);

        do_action( 'adventure_blog_before_social_menu');

        $style = $instance['style'];

        ?>
        <div class="adventure-blog-social-menu-widget <?php echo esc_attr($style);?>">
            <?php

            if ( has_nav_menu( 'social' ) ) {
                wp_nav_menu(array(
                    'theme_location' => 'social',
                    'container_class' => 'social-navigation-widget',
                    'fallback_cb' => false,
                    'depth' => 1,
                    'menu_class' => 'adventure-blog-social-icons',
                    'link_before' => '<span class="social-media-title">',
                    'link_after' => '</span>',
                ) );
            }else{
                esc_html_e( 'Social menu is not set. You need to create menu and assign it to Social Menu on Menu Settings.', 'adventure-blog' );
            }
            ?>
        </div>
        <?php

        do_action( 'adventure_blog_after_social_menu');

        $this->widget_end($args);

        echo ob_get_clean();
    }
}